<?php

ini_set('highlight.string','#008800');
ini_set('highlight.comment','#969696');
ini_set('highlight.keyword','#0000DD');
ini_set('highlight.default','#444444');
ini_set('highlight.html','#0000FF');

function BbCodeTag($tag, $part)
{
	switch($tag){
		case 'b':
			$part = '<strong>'.$part.'</strong>';
			break;
		case 'i':
			$part = '<em>'.$part.'</em>';
			break;
		case 'u':
			$part = '<span style="text-decoration: underline;">'.$part.'</span>';
			break;
		case 's':
			$part = '<span style="text-decoration: line-through;">'.$part.'</span>';
			break;
		case 'code':
			$part = str_replace("\t", '&nbsp;&nbsp;&nbsp;&nbsp;', $part);
			$part = '<div class="bbcode_code">'.'<code>'.$part.'</code></div>';
			break;
		case 'php':
			$part = str_replace('<br />', '', $part);
			$part = htmlspecialchars_decode($part);
			if(substr($part, 0, 2) != '<?'){
				$part = "<?\n".$part."\n?>";
			}
			$part = '<div class="bbcode_php">'.highlight_string($part, true).'</div>';
			break;
		case 'left':
			$part = '<p style="text-align: left;">'.$part.'</p>';
			break;
		case 'center':
			$part = '<p style="text-align: center;">'.$part.'</p>';
			break;
		case 'right':
			$part = '<p style="text-align: right;">'.$part.'</p>';
			break;
		case 'justify':
			$part = '<p style="text-align: justify;">'.$part.'</p>';
			break;
		case 'quote':
			$part = '<div class="bbcode_quote">'.$part.'</div>';
			break;
		case 'url':
			$part = '<a href="'.UrlRender($part).'" target="_blank">'.$part.'</a>';
			break;
		case 'img':
			$part = '<img src="'.$part.'" />';
			break;
	}
	return $part;
}

function BbCodePreparePart( $Parts )
{
	$existing_tags = array(
		'',
		'b',
		'i',
		'u',
		's',
		'left',
		'center',
		'right',
		'justify',
		'code',
		'php',
		'quote',
		'img',
		'url'
	);

	$active_tag = '';
	$tag_open = false;
	$sub_parts = array();
	$result_parts = array();
	foreach($Parts as $part){
		$part2 = trim($part);
		$matches = array();

		//  
		if(preg_match('#^\[([a-z]+)([^\]]+)?\]$#', $part2, $matches)){
			if(!$tag_open && array_search($matches[1], $existing_tags) !== false){
				$tag_open = true;
				$active_tag = $matches[1];
			}else{
				$sub_parts[] = $part;
			}
			continue;
		}elseif(preg_match('#^\[/([a-z]+)\]$#', $part2, $matches)){ //  
			if($tag_open && $matches[1] == $active_tag){
				if($active_tag == 'php' || $active_tag == 'code'){
					$result_parts[] = BbCodeTag($active_tag, implode('', $sub_parts));
				}else{
					$result_parts[] = BbCodeTag($active_tag, BbCodePreparePart($sub_parts));
				}
				$active_tag = '';
				$tag_open = false;
				$sub_parts = array();
			}else{
				$sub_parts[] = $part;
			}
			continue;
		}elseif($tag_open){
			$sub_parts[] = $part;
		}else{
			$result_parts[] = $part;
		}
	}
	return implode('', $result_parts);
}

function BbCodePrepare( $string )
{
	$string = trim($string);
	$parts = preg_split('#(\[/?[^\]]+\])#', $string, -1, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
	return BbCodePreparePart( $parts );
}

?>